@@ -24,7 +24,7 @@ from naas_drivers.in_out_drivers.Toucan import Toucan
 import requests
 import os
 
-__version__ = "0.24.3"
+__version__ = "0.24.8"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -37,7 +37,7 @@ geolocator = Geolocator()
 newsapi = Newsapi()
 prediction = Prediction()
 sentiment = Sentiment()
-yahoo_finance = YahooFinance()
+yahoofinance = YahooFinance()
 pdf = Pdf()
 plotly = Plotly()
 html = Html()
@@ -45,7 +45,7 @@ html = Html()
 # Out drivers
 bubble = Bubble()
 email = Email()
-health_check = Healthcheck()
+healthcheck = Healthcheck()
 ifttt = Ifttt()
 integromat = Integromat()
 zappier = Zappier()
